PROGRAM_NAME='Main, RMS 4_6, Base'
#include 'SNAPI';
#include 'G4API';


(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

    dvMASTER 		= 0:1:0;

    dvIP_BSS_BLU	= 0:3:0;	// Blu50 Audio DSP at Student Station
    dvIP_ROKU		= 0:4:0;	// Roku STB at Student Station

    dvIP_LIGHTS		= 0:5:0;	// Loopback lighting device

    dvDVX_IR_APPLETV	= 5001:11:0;	// Apple TV IR

    dvDVX_REL		= 5001:21:0;	// Relays
					    // 1 = Screen Up
					    // 2 = Screen Down
					    // 3 = Lift Up
					    // 4 = Lift Down

    dvDVX_IO		= 5001:22:0;	// IOs	
					    // 1 = Shades Open
					    // 2 = Shades Close

    dvDVX_SWITCHER_IO_1	= 5002:1:0;	// / Amp out
    dvDVX_SWITCHER_IO_2	= 5002:2:0;	// DVD In (emulated source)
    dvDVX_SWITCHER_IO_3	= 5002:3:0;	// Apple TV In / Display Out (DXLink)
    dvDVX_SWITCHER_IN_4	= 5002:4:0;	// Roku In
    dvDVX_SWITCHER_IN_5	= 5002:5:0;	// Enzo In (DXLink)
    dvDVX_SWITCHER_IN_6	= 5002:6:0;	// Laptop In (DXLink)

    dvDXLINK_TX_1	= 5301:1:0;	// Enzo TX
    dvDXLINK_TX_2	= 5302:1:0;	// Laptop TX

    dvDXLINK_RX_1	= 5401:1:0;	// Display RX

    dvENZO		= 6001:1:0;

    dvRS232_PROJECTOR	= 5001:2:0;	// Video Projector 	: Dummy loopback device	

    dvTP_1		= 10001:1:0;
    dvTP_1_ROKU		= 10001:2:0;
    dvTP_1_APPLE	= 10001:3:0;
    dvTP_1_LIGHTS	= 10001:4:0;
    dvTP_1_DSP		= 10001:5:0;
    dvTP_1_ENZO		= 10001:6:0;

    vdvLIGHTS		= 33001:1:0;
    vdvPROJECTOR	= 33002:1:0;

    vdvBSS_BLU_1	= 41101:1:0;
    vdvBSS_BLU_2	= 41101:2:0;	// Room Out Volume
    vdvBSS_BLU_3	= 41101:3:0;	// Mic Mixer Input Gain 
    vdvBSS_BLU_4	= 41101:4:0;	// VTC Input Gain

    vdvROKU		= 41102:1:0;


(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT
    // Relay constants
    integer SCREEN_UP	 = 1;
    integer SCREEN_DOWN  = 2;
    integer LIFT_UP	 = 3;
    integer LIFT_DOWN	 = 4;
    // IO constants
    integer SHADES_OPEN	 = 1;
    integer SHADES_CLOSE = 2;
    
    integer DVX_STANDBY	 = 100;
    
#WARN 'SET DEVICE COMMUNICATION PROPERTIES AT CONSTANT DEFINITIONS'
    // Lights - Just a dummy, can be anything
    char IP_ADDRESS_LIGHTS[ ]	= '10.10.31.101';	
    // Roku - Set to the address of the device assigned to your station
    char IP_ADDRESS_ROKU[ ] 	= '172.21.90.102';	
    // BSS Blu50 - Set to the address of the device assigned to your station
    char IP_ADDRESS_DSP[ ]  	= '172.21.90.104';	
    char DEVICE_ID_DSP[ ] 	= '0x7980';


(***********************************************************)
(*               TIMELINE DEFINITIONS GO BELOW             *)
(***********************************************************)
    long TL_SYSTEM_FB	 = 1;
    
    
(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

([dvDVX_REL, SCREEN_UP], [dvDVX_REL, SCREEN_DOWN])
([dvDVX_REL, LIFT_UP], [dvDVX_REL, LIFT_DOWN])
([dvDVX_IO, SHADES_OPEN], [dvDVX_IO, SHADES_CLOSE])


#include 'Roku';
#include 'AppleTV';
#include 'Enzo';
#include 'BSSBlu50';
#include 'Lighting';
#include 'System';


(***********************************************************)
(*                 STARTUP CODE GOES BELOW                 *)
(***********************************************************)
DEFINE_START


(***********************************************************)
(*               MODULE DEFINITIONS GO BELOW               *)
(***********************************************************)
DEFINE_MODULE
    'BSS_BLU50_Comm_dr2_0_0' 	mdlBSS_BLU50_Comm_dr2_0_0(vdvBSS_BLU_1, dvIP_BSS_BLU);
    'Roku_Comm_dr1_0_0' 	mdlRoku_Comm_dr1_0_0(vdvROKU, dvIP_ROKU);
    'CommSCOLightAmp' 		mdlCommSCOLightAmp(vdvPROJECTOR, dvRS232_PROJECTOR);
    'CommZ10Lights' 		mdlCommZ10Lights(vdvLIGHTS, dvIP_LIGHTS);



